@@ -12,7 +12,6 @@ from typing import AsyncIterator, List, Optional, Sequence, Set, Tuple
 import async_timeout
 import click
 from dateutil.parser import isoparse
-from rich.table import Table
 from yarl import URL
 
 from neuro_sdk import (
@@ -518,20 +517,6 @@ async def bump_life_span(root: Root, job: str, additional_life_span: str) -> Non
         )
 
 
-@command(deprecated=True, hidden=True)
-async def tags(root: Root) -> None:
-    """
-    List all tags submitted by the user.
-    """
-    res = await root.client.jobs.tags()
-    table = Table.grid()
-    table.add_column("")
-    for item in res:
-        table.add_row(item)
-    with root.pager():
-        root.print(table)
-
-
 @command()
 @click.argument("job", type=JOB)
 async def browse(root: Root, job: str) -> None:
@@ -859,6 +844,14 @@ async def kill(root: Root, jobs: Sequence[str]) -> None:
     "--http",
     type=int,
     metavar="PORT",
+    default=None,
+    help="Enable HTTP port forwarding to container (use --http-port instead)",
+    hidden=True,
+)
+@option(
+    "--http-port",
+    type=int,
+    metavar="PORT",
     default=80,
     show_default=True,
     help="Enable HTTP port forwarding to container",
@@ -1023,7 +1016,8 @@ async def run(
     cluster: Optional[str],
     org: Optional[str],
     extshm: bool,
-    http: int,
+    http: Optional[int],
+    http_port: int,
     http_auth: Optional[bool],
     entrypoint: Optional[str],
     cmd: Sequence[str],
@@ -1067,6 +1061,12 @@ async def run(
     # registry, run /script.sh and pass arg1 and arg2 as its arguments:
     neuro run -s cpu-small --entrypoint=/script.sh image:my-ubuntu:latest -- arg1 arg2
     """
+    if http is not None:
+        root.console.print("[red]--http option is deprecated,", markup=True)
+        root.console.print(
+            "[red]Please use  --http-port option instead of --http", markup=True
+        )
+        http_port = http
     cmd = _fix_cmd("neuro run", "IMAGE -- CMD...", cmd)
     cluster_name = cluster or root.client.cluster_name
     org_name = org or root.client.config.org_name
@@ -1084,7 +1084,7 @@ async def run(
         image=image,
         preset=preset,
         extshm=extshm,
-        http=http,
+        http_port=http_port,
         http_auth=http_auth,
         entrypoint=entrypoint,
         cmd=cmd,
@@ -1137,7 +1137,6 @@ job.add_command(run)
 job.add_command(generate_run_command)
 job.add_command(ls)
 job.add_command(status)
-job.add_command(tags)
 job.add_command(exec)
 job.add_command(port_forward)
 job.add_command(logs)
@@ -1155,7 +1154,7 @@ async def run_job(
     image: RemoteImage,
     preset: str,
     extshm: bool,
-    http: Optional[int],
+    http_port: Optional[int],
     http_auth: Optional[bool],
     entrypoint: Optional[str],
     cmd: Sequence[str],
@@ -1183,13 +1182,13 @@ async def run_job(
 ) -> JobDescription:
     if http_auth is None:
         http_auth = True
-    elif not http:
+    elif not http_port:
         if http_auth:
-            raise click.UsageError("--http-auth requires --http")
+            raise click.UsageError("--http-auth requires --http-port")
         else:
-            raise click.UsageError("--no-http-auth requires --http")
-    if browse and not http:
-        raise click.UsageError("--browse requires --http")
+            raise click.UsageError("--no-http-auth requires --http-port")
+    if browse and not http_port:
+        raise click.UsageError("--browse requires --http-port")
     if browse and not wait_start:
         raise click.UsageError("Cannot use --browse and --no-wait-start together")
     if not wait_start:
@@ -1257,7 +1256,7 @@ async def run_job(
         entrypoint=entrypoint,
         command=real_cmd,
         working_dir=working_dir,
-        http=HTTPPort(http, http_auth) if http else None,
+        http=HTTPPort(http_port, http_auth) if http_port else None,
         env=env_dict,
         volumes=volumes,
         secret_env=secret_env_dict,
@@ -1399,7 +1398,7 @@ def _job_to_cli_args(job: JobDescription) -> List[str]:
         res += ["--no-extshm"]
     if job.container.http:
         if job.container.http.port != 80:
-            res += ["--http", str(job.container.http.port)]
+            res += ["--http-port", str(job.container.http.port)]
         if not job.container.http.requires_auth:
             res += ["--no-http-auth"]
     if job.name:
